summaryrefslogtreecommitdiffstats
path: root/chrome/common/render_messages_internal.h
diff options
context:
space:
mode:
authorjeremy@chromium.org <jeremy@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-04-29 14:06:14 +0000
committerjeremy@chromium.org <jeremy@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-04-29 14:06:14 +0000
commitbc0c3ba245f12d916dbf028cee9a602bda2550f9 (patch)
tree348362d01cb7eb1bab1e4ff83ccaab3cb4fc1381 /chrome/common/render_messages_internal.h
parentc7189e191b90798715edcdf8b2edaa2c0c29f3cd (diff)
downloadchromium_src-bc0c3ba245f12d916dbf028cee9a602bda2550f9.zip
chromium_src-bc0c3ba245f12d916dbf028cee9a602bda2550f9.tar.gz
chromium_src-bc0c3ba245f12d916dbf028cee9a602bda2550f9.tar.bz2
Cleanup: Rename OnLoadFont->OnPreCacheFont
I'm working on a Mac specific change where we'll need an IPC message to load a font and pass the font data back to the renderer process. To prevent confusion this CL preemptively renames a Windows message which actually causes a font to be cached by the browser. The distinction between these two operations is subtle but I thought it best to try to prevent future confusion by making sure the IPC messages don't have similar names. BUG=None TEST=None Review URL: http://codereview.chromium.org/1805002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@45931 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common/render_messages_internal.h')
-rw-r--r--chrome/common/render_messages_internal.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/common/render_messages_internal.h b/chrome/common/render_messages_internal.h
index 60c4cab..d575873 100644
--- a/chrome/common/render_messages_internal.h
+++ b/chrome/common/render_messages_internal.h
@@ -1407,9 +1407,9 @@ IPC_BEGIN_MESSAGES(ViewHost)
#endif
#if defined(OS_WIN)
- // Request that the given font be loaded by the browser.
- // Please see ResourceMessageFilter::OnLoadFont for details.
- IPC_SYNC_MESSAGE_CONTROL1_0(ViewHostMsg_LoadFont,
+ // Request that the given font be loaded by the browser so it's cached by the
+ // OS. Please see ResourceMessageFilter::OnPreCacheFont for details.
+ IPC_SYNC_MESSAGE_CONTROL1_0(ViewHostMsg_PreCacheFont,
LOGFONT /* font data */)
#endif // defined(OS_WIN)